# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/profile.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import postal_address_pb2 as google_dot_type_dot_postal__address__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/profile.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\024ProfileResourceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n/google/cloud/talent_v4beta1/proto/profile.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a google/type/postal_address.proto\x1a\x1cgoogle/api/annotations.proto"\xf6\r\n\x07Profile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x10\n\x08group_id\x18\x05 \x01(\t\x12.\n\nis_hirable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15\x63\x61ndidate_update_time\x18\x43 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12resume_update_time\x18\x44 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x06resume\x18\x35 \x01(\x0b\x32#.google.cloud.talent.v4beta1.Resume\x12=\n\x0cperson_names\x18\x0b \x03(\x0b\x32\'.google.cloud.talent.v4beta1.PersonName\x12\x37\n\taddresses\x18\x0c \x03(\x0b\x32$.google.cloud.talent.v4beta1.Address\x12;\n\x0f\x65mail_addresses\x18\r \x03(\x0b\x32".google.cloud.talent.v4beta1.Email\x12\x39\n\rphone_numbers\x18\x0e \x03(\x0b\x32".google.cloud.talent.v4beta1.Phone\x12?\n\rpersonal_uris\x18\x0f \x03(\x0b\x32(.google.cloud.talent.v4beta1.PersonalUri\x12S\n\x17\x61\x64\x64itional_contact_info\x18\x10 \x03(\x0b\x32\x32.google.cloud.talent.v4beta1.AdditionalContactInfo\x12I\n\x12\x65mployment_records\x18\x11 \x03(\x0b\x32-.google.cloud.talent.v4beta1.EmploymentRecord\x12G\n\x11\x65\x64ucation_records\x18\x12 \x03(\x0b\x32,.google.cloud.talent.v4beta1.EducationRecord\x12\x32\n\x06skills\x18\x13 \x03(\x0b\x32".google.cloud.talent.v4beta1.Skill\x12\x39\n\nactivities\x18\x14 \x03(\x0b\x32%.google.cloud.talent.v4beta1.Activity\x12>\n\x0cpublications\x18\x15 \x03(\x0b\x32(.google.cloud.talent.v4beta1.Publication\x12\x34\n\x07patents\x18\x16 \x03(\x0b\x32#.google.cloud.talent.v4beta1.Patent\x12\x42\n\x0e\x63\x65rtifications\x18\x17 \x03(\x0b\x32*.google.cloud.talent.v4beta1.Certification\x12\x19\n\x0c\x61pplications\x18/ \x03(\tB\x03\xe0\x41\x03\x12\x18\n\x0b\x61ssignments\x18\x30 \x03(\tB\x03\xe0\x41\x03\x12U\n\x11\x63ustom_attributes\x18\x1a \x03(\x0b\x32:.google.cloud.talent.v4beta1.Profile.CustomAttributesEntry\x12\x16\n\tprocessed\x18\x1b \x01(\x08\x42\x03\xe0\x41\x03\x12\x1c\n\x0fkeyword_snippet\x18\x1c \x01(\tB\x03\xe0\x41\x03\x12R\n\x14\x61vailability_signals\x18\x46 \x03(\x0b\x32/.google.cloud.talent.v4beta1.AvailabilitySignalB\x03\xe0\x41\x03\x12\x45\n\x11\x64\x65rived_addresses\x18@ \x03(\x0b\x32%.google.cloud.talent.v4beta1.LocationB\x03\xe0\x41\x03\x1a\x65\n\x15\x43ustomAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.google.cloud.talent.v4beta1.CustomAttribute:\x02\x38\x01:X\xea\x41U\n\x1bjobs.googleapis.com/Profile\x12\x36projects/{project}/tenants/{tenant}/profiles/{profile}"\xc3\x01\n\x12\x41vailabilitySignal\x12\x41\n\x04type\x18\x01 \x01(\x0e\x32\x33.google.cloud.talent.v4beta1.AvailabilitySignalType\x12\x34\n\x10last_update_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10\x66ilter_satisfied\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue"\xb5\x01\n\x06Resume\x12\x19\n\x11structured_resume\x18\x01 \x01(\t\x12\x43\n\x0bresume_type\x18\x02 \x01(\x0e\x32..google.cloud.talent.v4beta1.Resume.ResumeType"K\n\nResumeType\x12\x1b\n\x17RESUME_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05HRXML\x10\x01\x12\x15\n\x11OTHER_RESUME_TYPE\x10\x02"\xbc\x02\n\nPersonName\x12\x18\n\x0e\x66ormatted_name\x18\x01 \x01(\tH\x00\x12W\n\x0fstructured_name\x18\x02 \x01(\x0b\x32<.google.cloud.talent.v4beta1.PersonName.PersonStructuredNameH\x00\x12\x16\n\x0epreferred_name\x18\x03 \x01(\t\x1a\x93\x01\n\x14PersonStructuredName\x12\x12\n\ngiven_name\x18\x01 \x01(\t\x12\x16\n\x0epreferred_name\x18\x06 \x01(\t\x12\x16\n\x0emiddle_initial\x18\x02 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x03 \x01(\t\x12\x10\n\x08suffixes\x18\x04 \x03(\t\x12\x10\n\x08prefixes\x18\x05 \x03(\tB\r\n\x0bperson_name"\xd9\x01\n\x07\x41\x64\x64ress\x12<\n\x05usage\x18\x01 \x01(\x0e\x32-.google.cloud.talent.v4beta1.ContactInfoUsage\x12\x1e\n\x14unstructured_address\x18\x02 \x01(\tH\x00\x12\x38\n\x12structured_address\x18\x03 \x01(\x0b\x32\x1a.google.type.PostalAddressH\x00\x12+\n\x07\x63urrent\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\t\n\x07\x61\x64\x64ress"\\\n\x05\x45mail\x12<\n\x05usage\x18\x01 \x01(\x0e\x32-.google.cloud.talent.v4beta1.ContactInfoUsage\x12\x15\n\remail_address\x18\x02 \x01(\t"\xcf\x02\n\x05Phone\x12<\n\x05usage\x18\x01 \x01(\x0e\x32-.google.cloud.talent.v4beta1.ContactInfoUsage\x12:\n\x04type\x18\x02 \x01(\x0e\x32,.google.cloud.talent.v4beta1.Phone.PhoneType\x12\x0e\n\x06number\x18\x03 \x01(\t\x12\x16\n\x0ewhen_available\x18\x04 \x01(\t"\xa3\x01\n\tPhoneType\x12\x1a\n\x16PHONE_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08LANDLINE\x10\x01\x12\n\n\x06MOBILE\x10\x02\x12\x07\n\x03\x46\x41X\x10\x03\x12\t\n\x05PAGER\x10\x04\x12\x0e\n\nTTY_OR_TDD\x10\x05\x12\r\n\tVOICEMAIL\x10\x06\x12\x0b\n\x07VIRTUAL\x10\x07\x12\x08\n\x04VOIP\x10\x08\x12\x16\n\x12MOBILE_OR_LANDLINE\x10\t"\x1a\n\x0bPersonalUri\x12\x0b\n\x03uri\x18\x01 \x01(\t"w\n\x15\x41\x64\x64itionalContactInfo\x12<\n\x05usage\x18\x01 \x01(\x0e\x32-.google.cloud.talent.v4beta1.ContactInfoUsage\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncontact_id\x18\x03 \x01(\t"\xf2\x03\n\x10\x45mploymentRecord\x12%\n\nstart_date\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12#\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x11.google.type.Date\x12\x15\n\remployer_name\x18\x03 \x01(\t\x12\x15\n\rdivision_name\x18\x04 \x01(\t\x12\x35\n\x07\x61\x64\x64ress\x18\x05 \x01(\x0b\x32$.google.cloud.talent.v4beta1.Address\x12\x11\n\tjob_title\x18\x06 \x01(\t\x12\x17\n\x0fjob_description\x18\x07 \x01(\t\x12\x31\n\ris_supervisor\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10is_self_employed\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\nis_current\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1e\n\x11job_title_snippet\x18\x0b \x01(\tB\x03\xe0\x41\x03\x12$\n\x17job_description_snippet\x18\x0c \x01(\tB\x03\xe0\x41\x03\x12"\n\x15\x65mployer_name_snippet\x18\r \x01(\tB\x03\xe0\x41\x03"\xcc\x03\n\x0f\x45\x64ucationRecord\x12%\n\nstart_date\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12#\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x11.google.type.Date\x12\x33\n\x18\x65xpected_graduation_date\x18\x03 \x01(\x0b\x32\x11.google.type.Date\x12\x13\n\x0bschool_name\x18\x04 \x01(\t\x12\x35\n\x07\x61\x64\x64ress\x18\x05 \x01(\x0b\x32$.google.cloud.talent.v4beta1.Address\x12\x1c\n\x12\x64\x65gree_description\x18\x06 \x01(\tH\x00\x12@\n\x11structured_degree\x18\x07 \x01(\x0b\x32#.google.cloud.talent.v4beta1.DegreeH\x00\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12.\n\nis_current\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12 \n\x13school_name_snippet\x18\n \x01(\tB\x03\xe0\x41\x03\x12\x1b\n\x0e\x64\x65gree_snippet\x18\x0b \x01(\tB\x03\xe0\x41\x03\x42\x08\n\x06\x64\x65gree"t\n\x06\x44\x65gree\x12<\n\x0b\x64\x65gree_type\x18\x01 \x01(\x0e\x32\'.google.cloud.talent.v4beta1.DegreeType\x12\x13\n\x0b\x64\x65gree_name\x18\x02 \x01(\t\x12\x17\n\x0f\x66ields_of_study\x18\x03 \x03(\t"\xd2\x02\n\x08\x41\x63tivity\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12&\n\x0b\x63reate_date\x18\x04 \x01(\x0b\x32\x11.google.type.Date\x12&\n\x0bupdate_date\x18\x05 \x01(\x0b\x32\x11.google.type.Date\x12\x14\n\x0cteam_members\x18\x06 \x03(\t\x12\x37\n\x0bskills_used\x18\x07 \x03(\x0b\x32".google.cloud.talent.v4beta1.Skill\x12"\n\x15\x61\x63tivity_name_snippet\x18\x08 \x01(\tB\x03\xe0\x41\x03\x12)\n\x1c\x61\x63tivity_description_snippet\x18\t \x01(\tB\x03\xe0\x41\x03\x12 \n\x13skills_used_snippet\x18\n \x03(\tB\x03\xe0\x41\x03"\xcb\x01\n\x0bPublication\x12\x0f\n\x07\x61uthors\x18\x01 \x03(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07journal\x18\x04 \x01(\t\x12\x0e\n\x06volume\x18\x05 \x01(\t\x12\x11\n\tpublisher\x18\x06 \x01(\t\x12+\n\x10publication_date\x18\x07 \x01(\x0b\x32\x11.google.type.Date\x12\x18\n\x10publication_type\x18\x08 \x01(\t\x12\x0c\n\x04isbn\x18\t \x01(\t"\xa9\x02\n\x06Patent\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x11\n\tinventors\x18\x02 \x03(\t\x12\x15\n\rpatent_status\x18\x03 \x01(\t\x12-\n\x12patent_status_date\x18\x04 \x01(\x0b\x32\x11.google.type.Date\x12-\n\x12patent_filing_date\x18\x05 \x01(\x0b\x32\x11.google.type.Date\x12\x15\n\rpatent_office\x18\x06 \x01(\t\x12\x15\n\rpatent_number\x18\x07 \x01(\t\x12\x1a\n\x12patent_description\x18\x08 \x01(\t\x12\x37\n\x0bskills_used\x18\t \x03(\x0b\x32".google.cloud.talent.v4beta1.SkillB\x82\x01\n\x1f\x63om.google.cloud.talent.v4beta1B\x14ProfileResourceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,
        google_dot_type_dot_date__pb2.DESCRIPTOR,
        google_dot_type_dot_postal__address__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_RESUME_RESUMETYPE = _descriptor.EnumDescriptor(
    name="ResumeType",
    full_name="google.cloud.talent.v4beta1.Resume.ResumeType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="RESUME_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="HRXML", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="OTHER_RESUME_TYPE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2463,
    serialized_end=2538,
)
_sym_db.RegisterEnumDescriptor(_RESUME_RESUMETYPE)

_PHONE_PHONETYPE = _descriptor.EnumDescriptor(
    name="PhoneType",
    full_name="google.cloud.talent.v4beta1.Phone.PhoneType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="PHONE_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="LANDLINE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MOBILE", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="FAX", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PAGER", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TTY_OR_TDD", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="VOICEMAIL", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="VIRTUAL", index=7, number=7, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="VOIP", index=8, number=8, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MOBILE_OR_LANDLINE",
            index=9,
            number=9,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3346,
    serialized_end=3509,
)
_sym_db.RegisterEnumDescriptor(_PHONE_PHONETYPE)


_PROFILE_CUSTOMATTRIBUTESENTRY = _descriptor.Descriptor(
    name="CustomAttributesEntry",
    full_name="google.cloud.talent.v4beta1.Profile.CustomAttributesEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.talent.v4beta1.Profile.CustomAttributesEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.talent.v4beta1.Profile.CustomAttributesEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1965,
    serialized_end=2066,
)

_PROFILE = _descriptor.Descriptor(
    name="Profile",
    full_name="google.cloud.talent.v4beta1.Profile",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.Profile.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="external_id",
            full_name="google.cloud.talent.v4beta1.Profile.external_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="source",
            full_name="google.cloud.talent.v4beta1.Profile.source",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.talent.v4beta1.Profile.uri",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="group_id",
            full_name="google.cloud.talent.v4beta1.Profile.group_id",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="is_hirable",
            full_name="google.cloud.talent.v4beta1.Profile.is_hirable",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="google.cloud.talent.v4beta1.Profile.create_time",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="google.cloud.talent.v4beta1.Profile.update_time",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="candidate_update_time",
            full_name="google.cloud.talent.v4beta1.Profile.candidate_update_time",
            index=8,
            number=67,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="resume_update_time",
            full_name="google.cloud.talent.v4beta1.Profile.resume_update_time",
            index=9,
            number=68,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="resume",
            full_name="google.cloud.talent.v4beta1.Profile.resume",
            index=10,
            number=53,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="person_names",
            full_name="google.cloud.talent.v4beta1.Profile.person_names",
            index=11,
            number=11,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="addresses",
            full_name="google.cloud.talent.v4beta1.Profile.addresses",
            index=12,
            number=12,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="email_addresses",
            full_name="google.cloud.talent.v4beta1.Profile.email_addresses",
            index=13,
            number=13,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="phone_numbers",
            full_name="google.cloud.talent.v4beta1.Profile.phone_numbers",
            index=14,
            number=14,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="personal_uris",
            full_name="google.cloud.talent.v4beta1.Profile.personal_uris",
            index=15,
            number=15,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="additional_contact_info",
            full_name="google.cloud.talent.v4beta1.Profile.additional_contact_info",
            index=16,
            number=16,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="employment_records",
            full_name="google.cloud.talent.v4beta1.Profile.employment_records",
            index=17,
            number=17,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="education_records",
            full_name="google.cloud.talent.v4beta1.Profile.education_records",
            index=18,
            number=18,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="skills",
            full_name="google.cloud.talent.v4beta1.Profile.skills",
            index=19,
            number=19,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="activities",
            full_name="google.cloud.talent.v4beta1.Profile.activities",
            index=20,
            number=20,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="publications",
            full_name="google.cloud.talent.v4beta1.Profile.publications",
            index=21,
            number=21,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="patents",
            full_name="google.cloud.talent.v4beta1.Profile.patents",
            index=22,
            number=22,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="certifications",
            full_name="google.cloud.talent.v4beta1.Profile.certifications",
            index=23,
            number=23,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="applications",
            full_name="google.cloud.talent.v4beta1.Profile.applications",
            index=24,
            number=47,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="assignments",
            full_name="google.cloud.talent.v4beta1.Profile.assignments",
            index=25,
            number=48,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="custom_attributes",
            full_name="google.cloud.talent.v4beta1.Profile.custom_attributes",
            index=26,
            number=26,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="processed",
            full_name="google.cloud.talent.v4beta1.Profile.processed",
            index=27,
            number=27,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="keyword_snippet",
            full_name="google.cloud.talent.v4beta1.Profile.keyword_snippet",
            index=28,
            number=28,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="availability_signals",
            full_name="google.cloud.talent.v4beta1.Profile.availability_signals",
            index=29,
            number=70,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="derived_addresses",
            full_name="google.cloud.talent.v4beta1.Profile.derived_addresses",
            index=30,
            number=64,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_PROFILE_CUSTOMATTRIBUTESENTRY],
    enum_types=[],
    serialized_options=_b(
        "\352AU\n\033jobs.googleapis.com/Profile\0226projects/{project}/tenants/{tenant}/profiles/{profile}"
    ),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=374,
    serialized_end=2156,
)


_AVAILABILITYSIGNAL = _descriptor.Descriptor(
    name="AvailabilitySignal",
    full_name="google.cloud.talent.v4beta1.AvailabilitySignal",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.talent.v4beta1.AvailabilitySignal.type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="last_update_time",
            full_name="google.cloud.talent.v4beta1.AvailabilitySignal.last_update_time",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter_satisfied",
            full_name="google.cloud.talent.v4beta1.AvailabilitySignal.filter_satisfied",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2159,
    serialized_end=2354,
)


_RESUME = _descriptor.Descriptor(
    name="Resume",
    full_name="google.cloud.talent.v4beta1.Resume",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="structured_resume",
            full_name="google.cloud.talent.v4beta1.Resume.structured_resume",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="resume_type",
            full_name="google.cloud.talent.v4beta1.Resume.resume_type",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_RESUME_RESUMETYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2357,
    serialized_end=2538,
)


_PERSONNAME_PERSONSTRUCTUREDNAME = _descriptor.Descriptor(
    name="PersonStructuredName",
    full_name="google.cloud.talent.v4beta1.PersonName.PersonStructuredName",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="given_name",
            full_name="google.cloud.talent.v4beta1.PersonName.PersonStructuredName.given_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="preferred_name",
            full_name="google.cloud.talent.v4beta1.PersonName.PersonStructuredName.preferred_name",
            index=1,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="middle_initial",
            full_name="google.cloud.talent.v4beta1.PersonName.PersonStructuredName.middle_initial",
            index=2,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="family_name",
            full_name="google.cloud.talent.v4beta1.PersonName.PersonStructuredName.family_name",
            index=3,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="suffixes",
            full_name="google.cloud.talent.v4beta1.PersonName.PersonStructuredName.suffixes",
            index=4,
            number=4,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="prefixes",
            full_name="google.cloud.talent.v4beta1.PersonName.PersonStructuredName.prefixes",
            index=5,
            number=5,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2695,
    serialized_end=2842,
)

_PERSONNAME = _descriptor.Descriptor(
    name="PersonName",
    full_name="google.cloud.talent.v4beta1.PersonName",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="formatted_name",
            full_name="google.cloud.talent.v4beta1.PersonName.formatted_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="structured_name",
            full_name="google.cloud.talent.v4beta1.PersonName.structured_name",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="preferred_name",
            full_name="google.cloud.talent.v4beta1.PersonName.preferred_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_PERSONNAME_PERSONSTRUCTUREDNAME],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="person_name",
            full_name="google.cloud.talent.v4beta1.PersonName.person_name",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=2541,
    serialized_end=2857,
)


_ADDRESS = _descriptor.Descriptor(
    name="Address",
    full_name="google.cloud.talent.v4beta1.Address",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="usage",
            full_name="google.cloud.talent.v4beta1.Address.usage",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="unstructured_address",
            full_name="google.cloud.talent.v4beta1.Address.unstructured_address",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="structured_address",
            full_name="google.cloud.talent.v4beta1.Address.structured_address",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="current",
            full_name="google.cloud.talent.v4beta1.Address.current",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="address",
            full_name="google.cloud.talent.v4beta1.Address.address",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=2860,
    serialized_end=3077,
)


_EMAIL = _descriptor.Descriptor(
    name="Email",
    full_name="google.cloud.talent.v4beta1.Email",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="usage",
            full_name="google.cloud.talent.v4beta1.Email.usage",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="email_address",
            full_name="google.cloud.talent.v4beta1.Email.email_address",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3079,
    serialized_end=3171,
)


_PHONE = _descriptor.Descriptor(
    name="Phone",
    full_name="google.cloud.talent.v4beta1.Phone",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="usage",
            full_name="google.cloud.talent.v4beta1.Phone.usage",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.talent.v4beta1.Phone.type",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="number",
            full_name="google.cloud.talent.v4beta1.Phone.number",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="when_available",
            full_name="google.cloud.talent.v4beta1.Phone.when_available",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_PHONE_PHONETYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3174,
    serialized_end=3509,
)


_PERSONALURI = _descriptor.Descriptor(
    name="PersonalUri",
    full_name="google.cloud.talent.v4beta1.PersonalUri",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.talent.v4beta1.PersonalUri.uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3511,
    serialized_end=3537,
)


_ADDITIONALCONTACTINFO = _descriptor.Descriptor(
    name="AdditionalContactInfo",
    full_name="google.cloud.talent.v4beta1.AdditionalContactInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="usage",
            full_name="google.cloud.talent.v4beta1.AdditionalContactInfo.usage",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.AdditionalContactInfo.name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="contact_id",
            full_name="google.cloud.talent.v4beta1.AdditionalContactInfo.contact_id",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3539,
    serialized_end=3658,
)


_EMPLOYMENTRECORD = _descriptor.Descriptor(
    name="EmploymentRecord",
    full_name="google.cloud.talent.v4beta1.EmploymentRecord",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="start_date",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.start_date",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end_date",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.end_date",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="employer_name",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.employer_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="division_name",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.division_name",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.address",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_title",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.job_title",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_description",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.job_description",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="is_supervisor",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.is_supervisor",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="is_self_employed",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.is_self_employed",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="is_current",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.is_current",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_title_snippet",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.job_title_snippet",
            index=10,
            number=11,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_description_snippet",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.job_description_snippet",
            index=11,
            number=12,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="employer_name_snippet",
            full_name="google.cloud.talent.v4beta1.EmploymentRecord.employer_name_snippet",
            index=12,
            number=13,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3661,
    serialized_end=4159,
)


_EDUCATIONRECORD = _descriptor.Descriptor(
    name="EducationRecord",
    full_name="google.cloud.talent.v4beta1.EducationRecord",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="start_date",
            full_name="google.cloud.talent.v4beta1.EducationRecord.start_date",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end_date",
            full_name="google.cloud.talent.v4beta1.EducationRecord.end_date",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="expected_graduation_date",
            full_name="google.cloud.talent.v4beta1.EducationRecord.expected_graduation_date",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="school_name",
            full_name="google.cloud.talent.v4beta1.EducationRecord.school_name",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="google.cloud.talent.v4beta1.EducationRecord.address",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="degree_description",
            full_name="google.cloud.talent.v4beta1.EducationRecord.degree_description",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="structured_degree",
            full_name="google.cloud.talent.v4beta1.EducationRecord.structured_degree",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.talent.v4beta1.EducationRecord.description",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="is_current",
            full_name="google.cloud.talent.v4beta1.EducationRecord.is_current",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="school_name_snippet",
            full_name="google.cloud.talent.v4beta1.EducationRecord.school_name_snippet",
            index=9,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="degree_snippet",
            full_name="google.cloud.talent.v4beta1.EducationRecord.degree_snippet",
            index=10,
            number=11,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="degree",
            full_name="google.cloud.talent.v4beta1.EducationRecord.degree",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=4162,
    serialized_end=4622,
)


_DEGREE = _descriptor.Descriptor(
    name="Degree",
    full_name="google.cloud.talent.v4beta1.Degree",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="degree_type",
            full_name="google.cloud.talent.v4beta1.Degree.degree_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="degree_name",
            full_name="google.cloud.talent.v4beta1.Degree.degree_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="fields_of_study",
            full_name="google.cloud.talent.v4beta1.Degree.fields_of_study",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4624,
    serialized_end=4740,
)


_ACTIVITY = _descriptor.Descriptor(
    name="Activity",
    full_name="google.cloud.talent.v4beta1.Activity",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.talent.v4beta1.Activity.display_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.talent.v4beta1.Activity.description",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.talent.v4beta1.Activity.uri",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="create_date",
            full_name="google.cloud.talent.v4beta1.Activity.create_date",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_date",
            full_name="google.cloud.talent.v4beta1.Activity.update_date",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="team_members",
            full_name="google.cloud.talent.v4beta1.Activity.team_members",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="skills_used",
            full_name="google.cloud.talent.v4beta1.Activity.skills_used",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="activity_name_snippet",
            full_name="google.cloud.talent.v4beta1.Activity.activity_name_snippet",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="activity_description_snippet",
            full_name="google.cloud.talent.v4beta1.Activity.activity_description_snippet",
            index=8,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="skills_used_snippet",
            full_name="google.cloud.talent.v4beta1.Activity.skills_used_snippet",
            index=9,
            number=10,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4743,
    serialized_end=5081,
)


_PUBLICATION = _descriptor.Descriptor(
    name="Publication",
    full_name="google.cloud.talent.v4beta1.Publication",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="authors",
            full_name="google.cloud.talent.v4beta1.Publication.authors",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.talent.v4beta1.Publication.title",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.talent.v4beta1.Publication.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="journal",
            full_name="google.cloud.talent.v4beta1.Publication.journal",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="volume",
            full_name="google.cloud.talent.v4beta1.Publication.volume",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="publisher",
            full_name="google.cloud.talent.v4beta1.Publication.publisher",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="publication_date",
            full_name="google.cloud.talent.v4beta1.Publication.publication_date",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="publication_type",
            full_name="google.cloud.talent.v4beta1.Publication.publication_type",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="isbn",
            full_name="google.cloud.talent.v4beta1.Publication.isbn",
            index=8,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5084,
    serialized_end=5287,
)


_PATENT = _descriptor.Descriptor(
    name="Patent",
    full_name="google.cloud.talent.v4beta1.Patent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.talent.v4beta1.Patent.display_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="inventors",
            full_name="google.cloud.talent.v4beta1.Patent.inventors",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="patent_status",
            full_name="google.cloud.talent.v4beta1.Patent.patent_status",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="patent_status_date",
            full_name="google.cloud.talent.v4beta1.Patent.patent_status_date",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="patent_filing_date",
            full_name="google.cloud.talent.v4beta1.Patent.patent_filing_date",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="patent_office",
            full_name="google.cloud.talent.v4beta1.Patent.patent_office",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="patent_number",
            full_name="google.cloud.talent.v4beta1.Patent.patent_number",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="patent_description",
            full_name="google.cloud.talent.v4beta1.Patent.patent_description",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="skills_used",
            full_name="google.cloud.talent.v4beta1.Patent.skills_used",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5290,
    serialized_end=5587,
)

_PROFILE_CUSTOMATTRIBUTESENTRY.fields_by_name[
    "value"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._CUSTOMATTRIBUTE
)
_PROFILE_CUSTOMATTRIBUTESENTRY.containing_type = _PROFILE
_PROFILE.fields_by_name[
    "is_hirable"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PROFILE.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROFILE.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROFILE.fields_by_name[
    "candidate_update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROFILE.fields_by_name[
    "resume_update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROFILE.fields_by_name["resume"].message_type = _RESUME
_PROFILE.fields_by_name["person_names"].message_type = _PERSONNAME
_PROFILE.fields_by_name["addresses"].message_type = _ADDRESS
_PROFILE.fields_by_name["email_addresses"].message_type = _EMAIL
_PROFILE.fields_by_name["phone_numbers"].message_type = _PHONE
_PROFILE.fields_by_name["personal_uris"].message_type = _PERSONALURI
_PROFILE.fields_by_name["additional_contact_info"].message_type = _ADDITIONALCONTACTINFO
_PROFILE.fields_by_name["employment_records"].message_type = _EMPLOYMENTRECORD
_PROFILE.fields_by_name["education_records"].message_type = _EDUCATIONRECORD
_PROFILE.fields_by_name[
    "skills"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._SKILL
_PROFILE.fields_by_name["activities"].message_type = _ACTIVITY
_PROFILE.fields_by_name["publications"].message_type = _PUBLICATION
_PROFILE.fields_by_name["patents"].message_type = _PATENT
_PROFILE.fields_by_name[
    "certifications"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._CERTIFICATION
)
_PROFILE.fields_by_name[
    "custom_attributes"
].message_type = _PROFILE_CUSTOMATTRIBUTESENTRY
_PROFILE.fields_by_name["availability_signals"].message_type = _AVAILABILITYSIGNAL
_PROFILE.fields_by_name[
    "derived_addresses"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._LOCATION
)
_AVAILABILITYSIGNAL.fields_by_name[
    "type"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._AVAILABILITYSIGNALTYPE
)
_AVAILABILITYSIGNAL.fields_by_name[
    "last_update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_AVAILABILITYSIGNAL.fields_by_name[
    "filter_satisfied"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_RESUME.fields_by_name["resume_type"].enum_type = _RESUME_RESUMETYPE
_RESUME_RESUMETYPE.containing_type = _RESUME
_PERSONNAME_PERSONSTRUCTUREDNAME.containing_type = _PERSONNAME
_PERSONNAME.fields_by_name[
    "structured_name"
].message_type = _PERSONNAME_PERSONSTRUCTUREDNAME
_PERSONNAME.oneofs_by_name["person_name"].fields.append(
    _PERSONNAME.fields_by_name["formatted_name"]
)
_PERSONNAME.fields_by_name[
    "formatted_name"
].containing_oneof = _PERSONNAME.oneofs_by_name["person_name"]
_PERSONNAME.oneofs_by_name["person_name"].fields.append(
    _PERSONNAME.fields_by_name["structured_name"]
)
_PERSONNAME.fields_by_name[
    "structured_name"
].containing_oneof = _PERSONNAME.oneofs_by_name["person_name"]
_ADDRESS.fields_by_name[
    "usage"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._CONTACTINFOUSAGE
)
_ADDRESS.fields_by_name[
    "structured_address"
].message_type = google_dot_type_dot_postal__address__pb2._POSTALADDRESS
_ADDRESS.fields_by_name[
    "current"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ADDRESS.oneofs_by_name["address"].fields.append(
    _ADDRESS.fields_by_name["unstructured_address"]
)
_ADDRESS.fields_by_name[
    "unstructured_address"
].containing_oneof = _ADDRESS.oneofs_by_name["address"]
_ADDRESS.oneofs_by_name["address"].fields.append(
    _ADDRESS.fields_by_name["structured_address"]
)
_ADDRESS.fields_by_name[
    "structured_address"
].containing_oneof = _ADDRESS.oneofs_by_name["address"]
_EMAIL.fields_by_name[
    "usage"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._CONTACTINFOUSAGE
)
_PHONE.fields_by_name[
    "usage"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._CONTACTINFOUSAGE
)
_PHONE.fields_by_name["type"].enum_type = _PHONE_PHONETYPE
_PHONE_PHONETYPE.containing_type = _PHONE
_ADDITIONALCONTACTINFO.fields_by_name[
    "usage"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._CONTACTINFOUSAGE
)
_EMPLOYMENTRECORD.fields_by_name[
    "start_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_EMPLOYMENTRECORD.fields_by_name[
    "end_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_EMPLOYMENTRECORD.fields_by_name["address"].message_type = _ADDRESS
_EMPLOYMENTRECORD.fields_by_name[
    "is_supervisor"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EMPLOYMENTRECORD.fields_by_name[
    "is_self_employed"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EMPLOYMENTRECORD.fields_by_name[
    "is_current"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EDUCATIONRECORD.fields_by_name[
    "start_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_EDUCATIONRECORD.fields_by_name[
    "end_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_EDUCATIONRECORD.fields_by_name[
    "expected_graduation_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_EDUCATIONRECORD.fields_by_name["address"].message_type = _ADDRESS
_EDUCATIONRECORD.fields_by_name["structured_degree"].message_type = _DEGREE
_EDUCATIONRECORD.fields_by_name[
    "is_current"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EDUCATIONRECORD.oneofs_by_name["degree"].fields.append(
    _EDUCATIONRECORD.fields_by_name["degree_description"]
)
_EDUCATIONRECORD.fields_by_name[
    "degree_description"
].containing_oneof = _EDUCATIONRECORD.oneofs_by_name["degree"]
_EDUCATIONRECORD.oneofs_by_name["degree"].fields.append(
    _EDUCATIONRECORD.fields_by_name["structured_degree"]
)
_EDUCATIONRECORD.fields_by_name[
    "structured_degree"
].containing_oneof = _EDUCATIONRECORD.oneofs_by_name["degree"]
_DEGREE.fields_by_name[
    "degree_type"
].enum_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._DEGREETYPE
_ACTIVITY.fields_by_name[
    "create_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_ACTIVITY.fields_by_name[
    "update_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_ACTIVITY.fields_by_name[
    "skills_used"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._SKILL
_PUBLICATION.fields_by_name[
    "publication_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_PATENT.fields_by_name[
    "patent_status_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_PATENT.fields_by_name[
    "patent_filing_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_PATENT.fields_by_name[
    "skills_used"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._SKILL
DESCRIPTOR.message_types_by_name["Profile"] = _PROFILE
DESCRIPTOR.message_types_by_name["AvailabilitySignal"] = _AVAILABILITYSIGNAL
DESCRIPTOR.message_types_by_name["Resume"] = _RESUME
DESCRIPTOR.message_types_by_name["PersonName"] = _PERSONNAME
DESCRIPTOR.message_types_by_name["Address"] = _ADDRESS
DESCRIPTOR.message_types_by_name["Email"] = _EMAIL
DESCRIPTOR.message_types_by_name["Phone"] = _PHONE
DESCRIPTOR.message_types_by_name["PersonalUri"] = _PERSONALURI
DESCRIPTOR.message_types_by_name["AdditionalContactInfo"] = _ADDITIONALCONTACTINFO
DESCRIPTOR.message_types_by_name["EmploymentRecord"] = _EMPLOYMENTRECORD
DESCRIPTOR.message_types_by_name["EducationRecord"] = _EDUCATIONRECORD
DESCRIPTOR.message_types_by_name["Degree"] = _DEGREE
DESCRIPTOR.message_types_by_name["Activity"] = _ACTIVITY
DESCRIPTOR.message_types_by_name["Publication"] = _PUBLICATION
DESCRIPTOR.message_types_by_name["Patent"] = _PATENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Profile = _reflection.GeneratedProtocolMessageType(
    "Profile",
    (_message.Message,),
    dict(
        CustomAttributesEntry=_reflection.GeneratedProtocolMessageType(
            "CustomAttributesEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_PROFILE_CUSTOMATTRIBUTESENTRY,
                __module__="google.cloud.talent_v4beta1.proto.profile_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Profile.CustomAttributesEntry)
            ),
        ),
        DESCRIPTOR=_PROFILE,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""A resource that represents the profile for a job candidate
  (also referred to as a "single-source profile").
  
  
  Attributes:
      name:
          Required during profile update.  Resource name assigned to a
          profile by the API.  The format is "projects/{project\_id}/ten
          ants/{tenant\_id}/profiles/{profile\_id}", for example,
          "projects/foo/tenants/bar/profiles/baz".
      external_id:
          Profile's id in client system, if available. This value is
          unique for each profile inside a tenant. An error is thrown if
          another profile with the same external\_id is created.  The
          maximum number of bytes allowed is 100.
      source:
          The source description indicating where the profile is
          acquired.  For example, if a candidate profile is acquired
          from a resume, the user can input "resume" here to indicate
          the source.  The maximum number of bytes allowed is 100.
      uri:
          The URI set by clients that links to this profile's client-
          side copy.  The maximum number of bytes allowed is 4000.
      group_id:
          The cluster id of the profile to associate with other
          profile(s) for the same candidate.  This field should be
          generated by the customer. If a value is not provided, a
          random UUID is assigned to this field of the profile.  This is
          used to link multiple profiles to the same candidate. For
          example, a client has a candidate with two profiles, where one
          was created recently and the other one was created 5 years
          ago. These two profiles may be very different. The clients can
          create the first profile and get a generated
          [group\_id][google.cloud.talent.v4beta1.Profile.group\_id],
          and assign it when the second profile is created, indicating
          these two profiles are referring to the same candidate.
      is_hirable:
          Indicates the hirable status of the candidate.
      create_time:
          The timestamp when the profile was first created at this
          source.
      update_time:
          The timestamp when the profile was last updated at this
          source.
      candidate_update_time:
          The timestamp when the profile was last updated as a result of
          a direct or indirect action by a candidate.  These actions
          include:  -  Direct actions such as the candidate submitting a
          new resume as part    of a job application to the agency,
          using a self-service tool such as    a website to update their
          profile, and so on. -  Indirect actions by the candidate such
          as uploading a resume to a job    board that is collected by
          the agency through a feed, providing a    resume to a
          recruiter who then uploads it into the ATS, and so on. -
          Updates made to the candidate's profile by the recruiter as a
          result    of interacting with the candidate (for example
          adding a skill or work    preference, and so on). Changes to
          [recruiting\_notes][google.cloud.talent.v4beta1.Profile.recrui
          ting\_notes]    are specifically excluded from this action
          type.  Note: [candidate\_update\_time][google.cloud.talent.v4b
          eta1.Profile.candidate\_update\_time] must be greater than or
          equal to [resume\_update\_time][google.cloud.talent.v4beta1.Pr
          ofile.resume\_update\_time] or an error is thrown.
      resume_update_time:
          The timestamp when the candidate's resume was added or updated
          on the candidate's profile. Whether that resume was directly
          uploaded by a candidate, pulled from a 3rd party job board
          feed, added by a recruiter, and so on.  If this field is
          updated, it's expected that
          [resume][google.cloud.talent.v4beta1.Profile.resume] is
          provided in the create or update calls.
      resume:
          The resume representing this profile.
      person_names:
          The names of the candidate this profile references.  Currently
          only one person name is supported.
      addresses:
          The candidate's postal addresses. It's highly recommended to
          input this information as accurately as possible to help
          improve search quality. Here are some recommendations:  -
          Provide
          [Address.usage][google.cloud.talent.v4beta1.Address.usage] if
          possible, especially if the address is PERSONAL. During a
          search only    personal addresses are considered. If there is
          no such address, all    addresses with unspecified usage are
          assumed to be personal. -  Provide
          [Address.current][google.cloud.talent.v4beta1.Address.current]
          for    the current address if possible. During a search, only
          current    addresses are considered. If there is no such
          address, all addresses    are assumed to be current.  When
          displaying a candidate's addresses, it is sometimes desirable
          to limit the number of addresses shown. In these cases we
          recommend that you display the addresses in the following
          order of priority: 1.
          [Address.usage][google.cloud.talent.v4beta1.Address.usage] is
          PERSONAL and
          [Address.current][google.cloud.talent.v4beta1.Address.current]
          is true. 2.
          [Address.usage][google.cloud.talent.v4beta1.Address.usage] is
          PERSONAL and
          [Address.current][google.cloud.talent.v4beta1.Address.current]
          is false or not set. 3.
          [Address.usage][google.cloud.talent.v4beta1.Address.usage] is
          CONTACT\_INFO\_USAGE\_UNSPECIFIED and
          [Address.current][google.cloud.talent.v4beta1.Address.current]
          is true. 4.
          [Address.usage][google.cloud.talent.v4beta1.Address.usage] is
          CONTACT\_INFO\_USAGE\_UNSPECIFIED and
          [Address.current][google.cloud.talent.v4beta1.Address.current]
          is false or not set.
      email_addresses:
          The candidate's email addresses.
      phone_numbers:
          The candidate's phone number(s).
      personal_uris:
          The candidate's personal URIs.
      additional_contact_info:
          Available contact information besides
          [addresses][google.cloud.talent.v4beta1.Profile.addresses], [e
          mail\_addresses][google.cloud.talent.v4beta1.Profile.email\_ad
          dresses], [phone\_numbers][google.cloud.talent.v4beta1.Profile
          .phone\_numbers] and [personal\_uris][google.cloud.talent.v4be
          ta1.Profile.personal\_uris]. For example, Hang-out, Skype.
      employment_records:
          The employment history records of the candidate. It's highly
          recommended to input this information as accurately as
          possible to help improve search quality. Here are some
          recommendations:  -  Specify the start and end dates of the
          employment records. -  List different employment types
          separately, no matter how minor the    change is. For example,
          only job title is changed from "software    engineer" to
          "senior software engineer". -  Provide    [EmploymentRecord.is
          \_current][google.cloud.talent.v4beta1.EmploymentRecord.is\_cu
          rrent]    for the current employment if possible. If not, it's
          inferred from    user inputs.  The limitation for max number
          of employment records is 100.
      education_records:
          The education history record of the candidate. It's highly
          recommended to input this information as accurately as
          possible to help improve search quality. Here are some
          recommendations:  -  Specify the start and end dates of the
          education records. -  List each education type separately, no
          matter how minor the change    is. For example, the profile
          contains the education experience from    the same school but
          different degrees. -  Provide    [EducationRecord.is\_current]
          [google.cloud.talent.v4beta1.EducationRecord.is\_current]
          for the current education if possible. If not, it's inferred
          from    user inputs.  The limitation for max number of
          education records is 100.
      skills:
          The skill set of the candidate. It's highly recommended to
          provide as much information as possible to help improve the
          search quality.  The limitation for max number of skills is
          500.
      activities:
          The individual or collaborative activities which the candidate
          has participated in, for example, open-source projects, class
          assignments that aren't listed in [employment\_records][google
          .cloud.talent.v4beta1.Profile.employment\_records].  The
          limitation for max number of activities is 50.
      publications:
          The publications published by the candidate.  The limitation
          for max number of publications is 50.
      patents:
          The patents acquired by the candidate.
      certifications:
          The certifications acquired by the candidate.
      applications:
          Output only. The resource names of the candidate's
          applications.
      assignments:
          Output only. The resource names of the candidate's
          assignments.
      custom_attributes:
          A map of fields to hold both filterable and non-filterable
          custom profile attributes that aren't covered by the provided
          structured fields. See
          [CustomAttribute][google.cloud.talent.v4beta1.CustomAttribute]
          for more details.  At most 100 filterable and at most 100
          unfilterable keys are supported. If limit is exceeded, an
          error is thrown. Custom attributes are ``unfilterable`` by
          default. These are filterable when the ``filterable`` flag is
          set to ``true``.  Numeric custom attributes: each key can only
          map to one numeric value, otherwise an error is thrown. Client
          can also filter on numeric custom attributes using '>', '<' or
          '=' operators.  String custom attributes: each key can map up
          to 50 string values. For filterable string value, each value
          has a byte size of no more than 256B. For unfilterable string
          values, the maximum byte size of a single key is 64B. An error
          is thrown for any request exceeding the limit. The maximum
          total byte size is 10KB.
      processed:
          Output only. Indicates if a summarized profile was created as
          part of the profile creation API call. This flag does not
          indicate whether a profile is searchable or not.
      keyword_snippet:
          Output only. Keyword snippet shows how the search result is
          related to a search query. This is only returned in [SearchPro
          filesResponse][google.cloud.talent.v4beta1.SearchProfilesRespo
          nse].
      availability_signals:
          Output only. Candidate's availability signals.
      derived_addresses:
          Output only. Derived locations of the profile, resolved from [
          Profile.addresses][google.cloud.talent.v4beta1.Profile.address
          es].  [derived\_addresses][google.cloud.talent.v4beta1.Profile
          .derived\_addresses] are exactly matched to [Profile.addresses
          ][google.cloud.talent.v4beta1.Profile.addresses] in the same
          order.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Profile)
    ),
)
_sym_db.RegisterMessage(Profile)
_sym_db.RegisterMessage(Profile.CustomAttributesEntry)

AvailabilitySignal = _reflection.GeneratedProtocolMessageType(
    "AvailabilitySignal",
    (_message.Message,),
    dict(
        DESCRIPTOR=_AVAILABILITYSIGNAL,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Candidate availability signal.
  
  
  Attributes:
      type:
          Type of signal.
      last_update_time:
          Timestamp of when the given availability activity last
          happened.
      filter_satisfied:
          Indicates if the [last\_update\_time][google.cloud.talent.v4be
          ta1.AvailabilitySignal.last\_update\_time] is within [Availabi
          lityFilter.range][google.cloud.talent.v4beta1.AvailabilityFilt
          er.range].  Returned only in a search response when there is
          an [AvailabilityFilter][google.cloud.talent.v4beta1.Availabili
          tyFilter] in [ProfileQuery.availability\_filters][google.cloud
          .talent.v4beta1.ProfileQuery.availability\_filters] where [sig
          nal\_type][google.cloud.talent.v4beta1.AvailabilityFilter.sign
          al\_type] matches
          [type][google.cloud.talent.v4beta1.AvailabilitySignal.type].
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.AvailabilitySignal)
    ),
)
_sym_db.RegisterMessage(AvailabilitySignal)

Resume = _reflection.GeneratedProtocolMessageType(
    "Resume",
    (_message.Message,),
    dict(
        DESCRIPTOR=_RESUME,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents a resume.
  
  
  Attributes:
      structured_resume:
          Users can create a profile with only this field field, if [res
          ume\_type][google.cloud.talent.v4beta1.Resume.resume\_type] is
          [HRXML][google.cloud.talent.v4beta1.Resume.ResumeType.HRXML].
          For example, the API parses this field and creates a profile
          with all structured fields populated. [EmploymentRecord][googl
          e.cloud.talent.v4beta1.EmploymentRecord], [EducationRecord][go
          ogle.cloud.talent.v4beta1.EducationRecord], and so on. An
          error is thrown if this field cannot be parsed.  Note that the
          use of the functionality offered by this field to extract data
          from resumes is an Alpha feature and as such is not covered by
          any SLA.
      resume_type:
          The format of [structured\_resume][google.cloud.talent.v4beta1
          .Resume.structured\_resume].
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Resume)
    ),
)
_sym_db.RegisterMessage(Resume)

PersonName = _reflection.GeneratedProtocolMessageType(
    "PersonName",
    (_message.Message,),
    dict(
        PersonStructuredName=_reflection.GeneratedProtocolMessageType(
            "PersonStructuredName",
            (_message.Message,),
            dict(
                DESCRIPTOR=_PERSONNAME_PERSONSTRUCTUREDNAME,
                __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
                __doc__="""Resource that represents a person's structured name.
    
    
    Attributes:
        given_name:
            Given/first name.  It's derived from [formatted\_name][google.
            cloud.talent.v4beta1.PersonName.formatted\_name] if not
            provided.  Number of characters allowed is 100.
        preferred_name:
            Preferred given/first name or nickname.  Number of characters
            allowed is 100.
        middle_initial:
            Middle initial.  It's derived from [formatted\_name][google.cl
            oud.talent.v4beta1.PersonName.formatted\_name] if not
            provided.  Number of characters allowed is 20.
        family_name:
            Family/last name.  It's derived from [formatted\_name][google.
            cloud.talent.v4beta1.PersonName.formatted\_name] if not
            provided.  Number of characters allowed is 100.
        suffixes:
            Suffixes.  Number of characters allowed is 20.
        prefixes:
            Prefixes.  Number of characters allowed is 20.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.PersonName.PersonStructuredName)
            ),
        ),
        DESCRIPTOR=_PERSONNAME,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents the name of a person.
  
  
  Attributes:
      person_name:
          The name of a person. It can be one of [formatted\_name][googl
          e.cloud.talent.v4beta1.PersonName.formatted\_name] or [structu
          red\_name][google.cloud.talent.v4beta1.PersonName.structured\_
          name].
      formatted_name:
          A string represents a person's full name. For example, "Dr.
          John Smith".  Number of characters allowed is 100.
      structured_name:
          A person's name in a structured way (last name, first name,
          suffix, and so on.)
      preferred_name:
          Preferred name for the person. This field is ignored if [struc
          tured\_name][google.cloud.talent.v4beta1.PersonName.structured
          \_name] is provided.  Number of characters allowed is 100.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.PersonName)
    ),
)
_sym_db.RegisterMessage(PersonName)
_sym_db.RegisterMessage(PersonName.PersonStructuredName)

Address = _reflection.GeneratedProtocolMessageType(
    "Address",
    (_message.Message,),
    dict(
        DESCRIPTOR=_ADDRESS,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents a address.
  
  
  Attributes:
      usage:
          The usage of the address. For example, SCHOOL, WORK, PERSONAL.
      address:
          The address of a person. It can be one of [unstructured\_addre
          ss][google.cloud.talent.v4beta1.Address.unstructured\_address]
          or [structured\_address][google.cloud.talent.v4beta1.Address.s
          tructured\_address].
      unstructured_address:
          Unstructured address.  For example, "1600 Amphitheatre Pkwy,
          Mountain View, CA 94043", "Sunnyvale, California".  Number of
          characters allowed is 100.
      structured_address:
          Structured address that contains street address, city, state,
          country, and so on.
      current:
          Indicates if it's the person's current address.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Address)
    ),
)
_sym_db.RegisterMessage(Address)

Email = _reflection.GeneratedProtocolMessageType(
    "Email",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EMAIL,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents a person's email address.
  
  
  Attributes:
      usage:
          The usage of the email address. For example, SCHOOL, WORK,
          PERSONAL.
      email_address:
          Email address.  Number of characters allowed is 4,000.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Email)
    ),
)
_sym_db.RegisterMessage(Email)

Phone = _reflection.GeneratedProtocolMessageType(
    "Phone",
    (_message.Message,),
    dict(
        DESCRIPTOR=_PHONE,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents a person's telephone number.
  
  
  Attributes:
      usage:
          The usage of the phone. For example, SCHOOL, WORK, PERSONAL.
      type:
          The phone type. For example, LANDLINE, MOBILE, FAX.
      number:
          Phone number.  Any phone formats are supported and only exact
          matches are performed on searches. For example, if a phone
          number in profile is provided in the format of "(xxx)xxx-
          xxxx", in profile searches the same phone format has to be
          provided.  Number of characters allowed is 20.
      when_available:
          When this number is available. Any descriptive string is
          expected.  Number of characters allowed is 100.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Phone)
    ),
)
_sym_db.RegisterMessage(Phone)

PersonalUri = _reflection.GeneratedProtocolMessageType(
    "PersonalUri",
    (_message.Message,),
    dict(
        DESCRIPTOR=_PERSONALURI,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents a valid URI for a personal use.
  
  
  Attributes:
      uri:
          The personal URI.  Number of characters allowed is 4,000.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.PersonalUri)
    ),
)
_sym_db.RegisterMessage(PersonalUri)

AdditionalContactInfo = _reflection.GeneratedProtocolMessageType(
    "AdditionalContactInfo",
    (_message.Message,),
    dict(
        DESCRIPTOR=_ADDITIONALCONTACTINFO,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents contact information other than
  phone, email, URI and addresses.
  
  
  Attributes:
      usage:
          The usage of this contact method. For example, SCHOOL, WORK,
          PERSONAL.
      name:
          The name of the contact method.  For example, "hangout",
          "skype".  Number of characters allowed is 100.
      contact_id:
          The contact id.  Number of characters allowed is 100.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.AdditionalContactInfo)
    ),
)
_sym_db.RegisterMessage(AdditionalContactInfo)

EmploymentRecord = _reflection.GeneratedProtocolMessageType(
    "EmploymentRecord",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EMPLOYMENTRECORD,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents an employment record of a
  candidate.
  
  
  Attributes:
      start_date:
          Start date of the employment.
      end_date:
          End date of the employment.
      employer_name:
          The name of the employer company/organization.  For example,
          "Google", "Alphabet", and so on.  Number of characters allowed
          is 250.
      division_name:
          The division name of the employment.  For example, division,
          department, client, and so on.  Number of characters allowed
          is 100.
      address:
          The physical address of the employer.
      job_title:
          The job title of the employment.  For example, "Software
          Engineer", "Data Scientist", and so on.  Number of characters
          allowed is 250.
      job_description:
          The description of job content.  Number of characters allowed
          is 100,000.
      is_supervisor:
          If the jobs is a supervisor position.
      is_self_employed:
          If this employment is self-employed.
      is_current:
          If this employment is current.
      job_title_snippet:
          Output only. The job title snippet shows how the [job\_title][
          google.cloud.talent.v4beta1.EmploymentRecord.job\_title] is
          related to a search query. It's empty if the [job\_title][goog
          le.cloud.talent.v4beta1.EmploymentRecord.job\_title] isn't
          related to the search query.
      job_description_snippet:
          Output only. The job description snippet shows how the [job\_d
          escription][google.cloud.talent.v4beta1.EmploymentRecord.job\_
          description] is related to a search query. It's empty if the [
          job\_description][google.cloud.talent.v4beta1.EmploymentRecord
          .job\_description] isn't related to the search query.
      employer_name_snippet:
          Output only. The employer name snippet shows how the [employer
          \_name][google.cloud.talent.v4beta1.EmploymentRecord.employer\
          _name] is related to a search query. It's empty if the [employ
          er\_name][google.cloud.talent.v4beta1.EmploymentRecord.employe
          r\_name] isn't related to the search query.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.EmploymentRecord)
    ),
)
_sym_db.RegisterMessage(EmploymentRecord)

EducationRecord = _reflection.GeneratedProtocolMessageType(
    "EducationRecord",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EDUCATIONRECORD,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents an education record of a
  candidate.
  
  
  Attributes:
      start_date:
          The start date of the education.
      end_date:
          The end date of the education.
      expected_graduation_date:
          The expected graduation date if currently pursuing a degree.
      school_name:
          The name of the school or institution.  For example, "Stanford
          University", "UC Berkeley", and so on.  Number of characters
          allowed is 250.
      address:
          The physical address of the education institution.
      degree:
          The degree information. It can be one of [degree\_description]
          [google.cloud.talent.v4beta1.EducationRecord.degree\_descripti
          on] or [structured\_degree][google.cloud.talent.v4beta1.Educat
          ionRecord.structured\_degree].
      degree_description:
          The full description of the degree.  For example, "Master of
          Science in Computer Science", "B.S in Math".  Number of
          characters allowed is 100.
      structured_degree:
          The structured notation of the degree.
      description:
          The description of the education.  Number of characters
          allowed is 100,000.
      is_current:
          If this education is current.
      school_name_snippet:
          Output only. The school name snippet shows how the [school\_na
          me][google.cloud.talent.v4beta1.EducationRecord.school\_name]
          is related to a search query in search result. It's empty if
          the [school\_name][google.cloud.talent.v4beta1.EducationRecord
          .school\_name] isn't related to the search query.
      degree_snippet:
          Output only. The job description snippet shows how the
          [Degree][google.cloud.talent.v4beta1.Degree] is related to a
          search query in search result. It's empty if the
          [Degree][google.cloud.talent.v4beta1.Degree] isn't related to
          the search query.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.EducationRecord)
    ),
)
_sym_db.RegisterMessage(EducationRecord)

Degree = _reflection.GeneratedProtocolMessageType(
    "Degree",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DEGREE,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents a degree pursuing or acquired by
  a candidate.
  
  
  Attributes:
      degree_type:
          ISCED degree type.
      degree_name:
          Full Degree name.  For example, "B.S.", "Master of Arts", and
          so on.  Number of characters allowed is 100.
      fields_of_study:
          Fields of study for the degree.  For example, "Computer
          science", "engineering".  Number of characters allowed is 100.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Degree)
    ),
)
_sym_db.RegisterMessage(Degree)

Activity = _reflection.GeneratedProtocolMessageType(
    "Activity",
    (_message.Message,),
    dict(
        DESCRIPTOR=_ACTIVITY,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents an individual or collaborative
  activity participated in by a candidate, for example, an open-source
  project, a class assignment, and so on.
  
  
  Attributes:
      display_name:
          Activity display name.  Number of characters allowed is 100.
      description:
          Activity description.  Number of characters allowed is
          100,000.
      uri:
          Activity URI.  Number of characters allowed is 4,000.
      create_date:
          The first creation date of the activity.
      update_date:
          The last update date of the activity.
      team_members:
          A list of team members involved in this activity.  Number of
          characters allowed is 100.  The limitation for max number of
          team members is 50.
      skills_used:
          A list of skills used in this activity.  The limitation for
          max number of skills used is 50.
      activity_name_snippet:
          Output only. Activity name snippet shows how the [display\_nam
          e][google.cloud.talent.v4beta1.Activity.display\_name] is
          related to a search query. It's empty if the [display\_name][g
          oogle.cloud.talent.v4beta1.Activity.display\_name] isn't
          related to the search query.
      activity_description_snippet:
          Output only. Activity description snippet shows how the [descr
          iption][google.cloud.talent.v4beta1.Activity.description] is
          related to a search query. It's empty if the [description][goo
          gle.cloud.talent.v4beta1.Activity.description] isn't related
          to the search query.
      skills_used_snippet:
          Output only. Skill used snippet shows how the corresponding [s
          kills\_used][google.cloud.talent.v4beta1.Activity.skills\_used
          ] are related to a search query. It's empty if the
          corresponding [skills\_used][google.cloud.talent.v4beta1.Activ
          ity.skills\_used] are not related to the search query.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Activity)
    ),
)
_sym_db.RegisterMessage(Activity)

Publication = _reflection.GeneratedProtocolMessageType(
    "Publication",
    (_message.Message,),
    dict(
        DESCRIPTOR=_PUBLICATION,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents a publication resource of a
  candidate.
  
  
  Attributes:
      authors:
          A list of author names.  Number of characters allowed is 100.
      title:
          The title of the publication.  Number of characters allowed is
          100.
      description:
          The description of the publication.  Number of characters
          allowed is 100,000.
      journal:
          The journal name of the publication.  Number of characters
          allowed is 100.
      volume:
          Volume number.  Number of characters allowed is 100.
      publisher:
          The publisher of the journal.  Number of characters allowed is
          100.
      publication_date:
          The publication date.
      publication_type:
          The publication type.  Number of characters allowed is 100.
      isbn:
          ISBN number.  Number of characters allowed is 100.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Publication)
    ),
)
_sym_db.RegisterMessage(Publication)

Patent = _reflection.GeneratedProtocolMessageType(
    "Patent",
    (_message.Message,),
    dict(
        DESCRIPTOR=_PATENT,
        __module__="google.cloud.talent_v4beta1.proto.profile_pb2",
        __doc__="""Resource that represents the patent acquired by a
  candidate.
  
  
  Attributes:
      display_name:
          Name of the patent.  Number of characters allowed is 100.
      inventors:
          A list of inventors' names.  Number of characters allowed for
          each is 100.
      patent_status:
          The status of the patent.  Number of characters allowed is
          100.
      patent_status_date:
          The date the last time the status of the patent was checked.
      patent_filing_date:
          The date that the patent was filed.
      patent_office:
          The name of the patent office.  Number of characters allowed
          is 100.
      patent_number:
          The number of the patent.  Number of characters allowed is
          100.
      patent_description:
          The description of the patent.  Number of characters allowed
          is 100,000.
      skills_used:
          The skills used in this patent.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Patent)
    ),
)
_sym_db.RegisterMessage(Patent)


DESCRIPTOR._options = None
_PROFILE_CUSTOMATTRIBUTESENTRY._options = None
_PROFILE.fields_by_name["applications"]._options = None
_PROFILE.fields_by_name["assignments"]._options = None
_PROFILE.fields_by_name["processed"]._options = None
_PROFILE.fields_by_name["keyword_snippet"]._options = None
_PROFILE.fields_by_name["availability_signals"]._options = None
_PROFILE.fields_by_name["derived_addresses"]._options = None
_PROFILE._options = None
_EMPLOYMENTRECORD.fields_by_name["job_title_snippet"]._options = None
_EMPLOYMENTRECORD.fields_by_name["job_description_snippet"]._options = None
_EMPLOYMENTRECORD.fields_by_name["employer_name_snippet"]._options = None
_EDUCATIONRECORD.fields_by_name["school_name_snippet"]._options = None
_EDUCATIONRECORD.fields_by_name["degree_snippet"]._options = None
_ACTIVITY.fields_by_name["activity_name_snippet"]._options = None
_ACTIVITY.fields_by_name["activity_description_snippet"]._options = None
_ACTIVITY.fields_by_name["skills_used_snippet"]._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.talent_v4beta1.proto import (
    application_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    application_service_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class ApplicationServiceStub(object):
    """A service that handles application management, including CRUD and
  enumeration.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateApplication = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ApplicationService/CreateApplication",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.CreateApplicationRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2.Application.FromString,
        )
        self.GetApplication = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ApplicationService/GetApplication",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.GetApplicationRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2.Application.FromString,
        )
        self.UpdateApplication = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ApplicationService/UpdateApplication",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.UpdateApplicationRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2.Application.FromString,
        )
        self.DeleteApplication = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ApplicationService/DeleteApplication",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.DeleteApplicationRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.ListApplications = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ApplicationService/ListApplications",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.ListApplicationsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.ListApplicationsResponse.FromString,
        )


class ApplicationServiceServicer(object):
    """A service that handles application management, including CRUD and
  enumeration.
  """

    def CreateApplication(self, request, context):
        """Creates a new application entity.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetApplication(self, request, context):
        """Retrieves specified application.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateApplication(self, request, context):
        """Updates specified application.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteApplication(self, request, context):
        """Deletes specified application.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListApplications(self, request, context):
        """Lists all applications associated with the profile.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ApplicationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateApplication": grpc.unary_unary_rpc_method_handler(
            servicer.CreateApplication,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.CreateApplicationRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2.Application.SerializeToString,
        ),
        "GetApplication": grpc.unary_unary_rpc_method_handler(
            servicer.GetApplication,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.GetApplicationRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2.Application.SerializeToString,
        ),
        "UpdateApplication": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateApplication,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.UpdateApplicationRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2.Application.SerializeToString,
        ),
        "DeleteApplication": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteApplication,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.DeleteApplicationRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "ListApplications": grpc.unary_unary_rpc_method_handler(
            servicer.ListApplications,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.ListApplicationsRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__service__pb2.ListApplicationsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.talent.v4beta1.ApplicationService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
